@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-import logging.handlers
 import socketserver
 
 from outflow.core.logging.stream_handler import StreamHandler
@@ -15,7 +14,7 @@ class SocketReceiver(socketserver.ThreadingTCPServer):
     def __init__(
         self,
         host="0.0.0.0",
-        port=logging.handlers.DEFAULT_TCP_LOGGING_PORT,
+        port=0,
         handler=StreamHandler,
     ):
         socketserver.ThreadingTCPServer.__init__(self, (host, port), handler)
