@@ -16,7 +16,9 @@ PLUGINS = [
 ]
 
 BACKENDS = {
-    "ray": "outflow.ray.backend",
+    "default": "outflow.core.backends.default",
+    "parallel": "outflow.core.backends.parallel",
+    "slurm": "outflow.slurm.backend",
 }
 
 ROOT_COMMAND_CLASS = RootCommand
