@@ -144,7 +144,9 @@ class Plugin:
 
         model_classes = inspect.getmembers(sys.modules[models_module_name], is_model)
 
-        for (module_loader, name, is_pkg) in pkgutil.iter_modules([models_dir_path]):
+        for (module_loader, name, is_pkg) in pkgutil.iter_modules(
+            [str(models_dir_path.resolve())]
+        ):
             submodule_name = models_module_name + "." + name
 
             # ensure the module is imported
