@@ -6,8 +6,8 @@ from subprocess import PIPE, STDOUT, Popen
 from typing import Dict, Iterable, List, Union
 
 from outflow.core.logging import logger
-from outflow.core.target import Target
 from outflow.core.pipeline import context
+from outflow.core.target import Target
 from outflow.core.tasks import Task
 
 from .control_flow_tasks import IdentityTask, IfThenElse, MergeTask  # noqa: F401
@@ -26,24 +26,35 @@ __all__ = [
 
 
 class PipelineArgs(Task):
-    def __init__(self, *args, **kwargs):
-        self.untracked_task = True
-        super().__init__(*args, auto_outputs=False, **kwargs)
-
-    def run(self, only: Union[None, Iterable] = None):
-        """Return the pipeline arguments as task outputs
+    def __init__(self, *args, only: Union[None, Iterable] = None, **kwargs):
+        """Task used to extract the pipeline arguments and pass them to the next task
 
         Args:
-            only (Union[None, Iterable], optional): If specified, return only the pipeline arguments listed. Defaults to None.
+            only (Union[None, Iterable], optional): If specified, create targets only for the pipeline arguments listed. Defaults to None.
+        """
+        self.untracked_task = True
+        super().__init__(*args, auto_outputs=False, **kwargs)
+        self._update_outputs(only=only)
+
+    def _update_outputs(self, only: Union[None, Iterable] = None):
+        """Update target outputs using pipeline arguments
+
+        Args:
+            only (Union[None, Iterable], optional): If specified, create targets only for the pipeline arguments listed. Defaults to None.
         """
-        pipeline_args = {}
         self.outputs = {}
 
-        # update target outputs and returned value using the pipeline args
         keys = vars(context.args) if only is None else only
 
         for key in keys:
             self.outputs.update({key: Target(name=key)})
+
+    def run(self):
+        """Return the pipeline arguments as task outputs"""
+        pipeline_args = {}
+
+        # return value using the pipeline args
+        for key in self.outputs:
             pipeline_args[key] = getattr(context.args, key)
         return pipeline_args
 
