@@ -9,16 +9,15 @@ def Management():
     pass
 
 
-@Management.subcommand(with_task_context=True)
-def DisplayConfig(self):
+@Management.subcommand()
+def DisplayConfig():
     print(config)
 
 
 @Management.subcommand(db_untracked=False)
 class Shell(Command):
     """
-    Run an interactive shell with access to the pipeline context. The shell is either a basic python interpreter
-    or an IPython interpreter depending on the presence of the flag --ipython
+    Run an interactive shell with access to the pipeline context.
     """
 
     def setup_tasks(self):
