@@ -14,6 +14,7 @@ class StateEnum(py_Enum):
     running = 2
     failed = 3
     success = 4
+    skipped = 5
 
 
 class Executable:
@@ -42,6 +43,13 @@ class Executable:
         self.end_time = datetime.datetime.now()
         session.commit()
 
+    @skip_if_untracked
+    def skip(self):
+        session = context.session
+        self.state = "skipped"
+        self.end_time = datetime.datetime.now()
+        session.commit()
+
     @skip_if_untracked
     def success(self):
         session = context.session
