@@ -27,10 +27,10 @@ class Task(Model, Executable):
         secondaryjoin="Task.id == Edge.upstream_task_id",
         backref="downstream_tasks",
     )
-    workflow_id = Column(
-        Integer, ForeignKey("workflow.id"), back_populates="tasks", nullable=False
+    workflow_id = Column(Integer, ForeignKey("workflow.id"), nullable=False)
+    workflow = relationship(
+        "Workflow", back_populates="tasks", foreign_keys=[workflow_id]
     )
-    workflow = relationship("Workflow", foreign_keys=[workflow_id])
 
 
 class Edge(Model):
